/* myMusic
 *
 * This program is distributed under the GNU General Public License, version 2.
 * A copy of this license is included with this source.
 *
 * Copyright 2004-2006, Toni Thomsson <toni@tonjac.org> 
*/

// Implementation of class Cmp3Config

#include <mp3_config.h>
#include <zz_log_exception.h>

// Construction
Cmp3Config::Cmp3Config( void )
{
	

}

// Destruction
Cmp3Config::~Cmp3Config()
{

}

CzzString Cmp3Config::getLicenseNo( void )
{
	CzzString lnr = "notregistred";

	try
	{
		lnr = getEntry( "lnr" );
	}
	catch( ... )
	{

	}

	return lnr;
}

CzzString Cmp3Config::getLocalRadioUrl( void )
{
	return getEntry( "local_radio_url" );
}

CzzString Cmp3Config::getLocalRadioName( void )
{
	return getEntry( "local_radio_name" );
}

CzzString Cmp3Config::getIsClosed( void )
{
	return getEntry( "closed" );
}

CzzString Cmp3Config::getWWWHost( void )
{
	return getEntry( "www_host" );
}

CzzString Cmp3Config::getMailHost( void )
{
	return getEntry( "mail_host" );
}

CzzString Cmp3Config::getCGIDir( void )
{		
	return getEntry( "cgi_dir" );
}

CzzString Cmp3Config::getLang( void )
{		
	return getEntry( "lang" );
}

CzzString Cmp3Config::getMusicRoot( void )
{		
	return getEntry( "music_root_dir" );
}

CzzString Cmp3Config::getSkin( void )
{		
	return getEntry( "skin" );
}

CzzString Cmp3Config::getSourceHost( void )
{		
	return getEntry( "source_host" );
}

CzzString Cmp3Config::getSourcePort( void )
{		
	return getEntry( "source_http_port" );
}

CzzString Cmp3Config::getRootDir( void )
{
	return getEntry( "root_dir" );
}

int Cmp3Config::getAdminUser( const CzzString& usr )
{
	CzzString vstr( "0" );

	try{ vstr = getEntry( "admin", usr ); } catch( ... ) {}

	return atoi( vstr.c_str() );
}

CzzString Cmp3Config::getIPUser( const CzzString& usr )
{
	CzzString vstr;

	try{ vstr = getEntry( "ip", usr ); } catch( ... ) {}

	return vstr;
}

CzzString Cmp3Config::getDataDir( void )
{
	CzzString result = getEntry( "lib_dir" );

	if( result[ result.size()-1 ] == '\\' )
		result = result.substr( 0, result.size()-1 );

	return result;
}

CzzString Cmp3Config::getM3uDir( void )
{
	return getEntry( "m3u_dir" );
}

CzzString Cmp3Config::getRadioDir( void )
{
	return getEntry( "radio_dir" );
}

CzzString Cmp3Config::getRealDir( void )
{
	return getEntry( "real_root" );
}

long Cmp3Config::getMaxResultSize( void )
{
	CzzString tmp = getEntry( "max_seek_result_records" );
	return atol( tmp.c_str() );
}

CzzString Cmp3Config::getAutoMail( void )
{
	return getEntry( "autosend_mail_on_error" );
}

CzzString Cmp3Config::getEntry( const CzzString& entry )
{
	return getEntry( "MP3-config", entry );
}

CzzString Cmp3Config::getEntry( const CzzString& block, const CzzString& entry )
{
	char var[ 256 ];

	if( !GetPrivateProfileString( block.c_str(), entry.c_str(), "", var, sizeof( var ), ".\\mp3.ini" ) )
		throw CzzLogException( _LAF, 4711, CzzString::Format( "Could not read configuration [%s] - '%s' from '%s'", block.c_str(), entry.c_str(), "mp3.ini" ) );
		
	return var;
}

void Cmp3Config::setEntry( const CzzString& entry, const CzzString& value )
{
	if( !WritePrivateProfileString( "MP3-config", entry.c_str(), value.c_str(), ".\\mp3.ini" ) )
		throw CzzLogException( _LAF, 4711, CzzString::Format( "Could not write configuration [MP3-config] - '%s' to '%s'", entry.c_str(), "mp3.ini" ) );
}


CzzString Cmp3Config::HEADLINE_ARTIST_INDEX( void )
{
	return getEntry( getLang(), "HEADLINE_ARTIST_INDEX" );	
}

CzzString Cmp3Config::HEADLINE_HELP( void )
{
	return getEntry( getLang(), "HEADLINE_HELP" );	
}

CzzString Cmp3Config::HEADLINE_ALBUM_INDEX( void )
{
	return getEntry( getLang(), "HEADLINE_ALBUM_INDEX" );	
}

CzzString Cmp3Config::HEADLINE_PLAYLIST_INDEX( void )
{
	return getEntry( getLang(), "HEADLINE_PLAYLIST_INDEX" );	
}

CzzString Cmp3Config::HEADLINE_PLAYLIST_CONTENT( void )
{
	return getEntry( getLang(), "HEADLINE_PLAYLIST_CONTENT" );	
}

CzzString Cmp3Config::HEADLINE_MYRADIO_INDEX_1( void )
{
	return getEntry( getLang(), "HEADLINE_MYRADIO_INDEX_1" );	
}

CzzString Cmp3Config::HEADLINE_MYRADIO_INDEX_2( void )
{
	return getEntry( getLang(), "HEADLINE_MYRADIO_INDEX_2" );	
}

CzzString Cmp3Config::HEADLINE_TEAMS_INDEX_1( void )
{
	return getEntry( getLang(), "HEADLINE_TEAMS_INDEX_1" );	
}

CzzString Cmp3Config::HEADLINE_TEAMS_INDEX_2( void )
{
	return getEntry( getLang(), "HEADLINE_TEAMS_INDEX_2" );	
}

CzzString Cmp3Config::HEADLINE_SEEK_1( void )
{
	return getEntry( getLang(), "HEADLINE_SEEK_1" );	
}

CzzString Cmp3Config::HEADLINE_SEEK_2( void )
{
	return getEntry( getLang(), "HEADLINE_SEEK_2" );	
}

CzzString Cmp3Config::HEADLINE_INFO( void )
{
	return getEntry( getLang(), "HEADLINE_INFO" );	
}


CzzString Cmp3Config::ALT_PLAY_LIST( void )
{
	return getEntry( getLang(), "ALT_PLAY_LIST" );	
}

CzzString Cmp3Config::ALT_PLAY_ALL_SONGS( void )
{
	return getEntry( getLang(), "ALT_PLAY_ALL_SONGS" );	
}

CzzString Cmp3Config::ALT_PLAY_ALL_ALBUMS( void )
{
	return getEntry( getLang(), "ALT_PLAY_ALL_ALBUMS" );	
}

CzzString Cmp3Config::ALT_PLAY_ALBUMS( void )
{
	return getEntry( getLang(), "ALT_PLAY_ALBUMS" );	
}

CzzString Cmp3Config::ALT_PLAY_CHANNEL( void )
{
	return getEntry( getLang(), "ALT_PLAY_CHANNEL" );	
}

CzzString Cmp3Config::SEEK_RESULT_1( void )
{
	return getEntry( getLang(), "SEEK_RESULT_1" );	
}

CzzString Cmp3Config::SEEK_RESULT_2( void )
{
	return getEntry( getLang(), "SEEK_RESULT_2" );	
}

CzzString Cmp3Config::SONGS( void )
{
	return getEntry( getLang(), "SONGS" );	
}

CzzString Cmp3Config::HEADLINE_PLAYLIST_NOTSAVED( void )
{
	return getEntry( getLang(), "HEADLINE_PLAYLIST_NOTSAVED" );	
}