/* myMusic
 *
 * This program is distributed under the GNU General Public License, version 2.
 * A copy of this license is included with this source.
 *
 * Copyright 2004-2006, Toni Thomsson <toni@tonjac.org> 
*/

// Implementation of class Cmp3HttpRequester

#include "mp3_http_requester.h"
#include <zz_base64.h>
#include "mp3_config.h"

// Construction
Cmp3HttpRequester::Cmp3HttpRequester( void )
: CzzHTTP( Cmp3Config::getSourceHost().c_str(), Cmp3Config::getSourcePort().c_str(), "myMusic", 5, 5 ), m_Log( "mp3_gui" ), m_User()
{
	CzzSocket::Init();
}

// Construction
Cmp3HttpRequester::Cmp3HttpRequester( char* host, char* port )
: CzzHTTP( host, port, "myMusic", 5, 5 ), m_Log( "mp3_gui" ), m_User()
{
	CzzSocket::Init();
}

// Destruction
Cmp3HttpRequester::~Cmp3HttpRequester()
{
	CzzSocket::Exit();
}

CzzString Cmp3HttpRequester::nowPlaying( void )
{
	m_Buffer = "";
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=5&usr=%s", getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );
	addRequest( "GET", url.c_str() );
		
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();

	return m_Buffer;
}

CzzString Cmp3HttpRequester::commingUp( void )
{
	m_Buffer = "";
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=6&usr=%s", getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();

	return m_Buffer;
}

void Cmp3HttpRequester::clearRadioQueue( void )
{
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=9&usr=%s", getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();
}

void Cmp3HttpRequester::skipForwardRadioQueue( void )
{
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=10&usr=%s", getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();
}

void Cmp3HttpRequester::skipReverseRadioQueue( void )
{
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=11&usr=%s", getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();
}

void Cmp3HttpRequester::addSongToRadioQueue( const char* name, const char* album, const char* song )
{
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=2&name=%s&album=%s&song=%s&usr=%s", name, album, song, getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();
}

void Cmp3HttpRequester::replaceRadioQueue( const char* name )
{
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=12&name=%s&usr=%s", name, getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();
}

void Cmp3HttpRequester::removeFromRadioQueue( const char* name, const char* album, const char* song )
{
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=3&name=%s&album=%s&song=%s&usr=%s", name, album, song, getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();
}

void Cmp3HttpRequester::randomizeRadioQueue( void )
{
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=13&usr=%s", getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();
}

CzzString Cmp3HttpRequester::listRadioQueue( void )
{
	m_Buffer = "";
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=4&usr=%s", getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();

	return m_Buffer;
}

CzzString Cmp3HttpRequester::listIndexesRadioQueue( void )
{
	m_Buffer = "";
	CzzString url = CzzString::Format( "/cgi-bin/mp3_radio.exe?svc=20&usr=%s", getUser().c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();

	return m_Buffer;
}

void Cmp3HttpRequester::writeToFile( long from, long size )
{
	char* tmp = new char[size+1];

	m_ReplyBuffer + from, size;
	memcpy( tmp, m_ReplyBuffer + from, size );
	tmp[size] = '\0';
	m_Buffer = m_Buffer + tmp;
	delete [] tmp;
}

CzzString Cmp3HttpRequester::checkLicense( const CzzString& lnr )
{
	m_Buffer = "";
	CzzString url = CzzString::Format( "/myMusic/cgi-bin/mp3_license.exe?id=%s", lnr.c_str() );
	m_ResponseFile = "";
	char localhost[ 256 ];
    gethostname( localhost, sizeof(localhost) );

	addRequest( "GET", url.c_str() );
	
	addHeader( "Host: %s", localhost );
	addHeader( "User-Agent: libzzinet/1.0 (%s)", m_UserAgent.c_str() );
	addHeader( "Accept: %s", "application/vnd.ms-excel, application/msword, application/vnd.ms-powerpoint, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */*" );
	addHeader( "Connection: %s", "close" );
	addEndMarker();

	send();

	delete m_SendBuffer;
	m_SendBuffer = NULL;

	reply();

	return m_Buffer;
}

CzzString Cmp3HttpRequester::getUser( void )
{

	if( m_User.size() <= 0 )
	{
		char* u = getenv( "REMOTE_USER" );
	
		if( u != NULL )
			m_User = u;
		else
			m_User = "unknown";
	}

	return m_User;
}