/* myMusic
 *
 * This program is distributed under the GNU General Public License, version 2.
 * A copy of this license is included with this source.
 *
 * Copyright 2004-2006, Toni Thomsson <toni@tonjac.org> 
*/

// Implementation of class Cmp3RecordData

#include "mp3_http_requester.h"
#include "mp3_record_data.h"
#include "mp3_svc.h"
#include "mp3_config.h"

#include <time.h>
#include <sys/timeb.h>
#include <sys/types.h> 
#include <id3/tag.h>
#include <zz_file.h>
#include <winver.h>

// Construction
Cmp3RecordData::Cmp3RecordData( const CzzString& added_radio )
: CzzDataService( "getRecordData" ), m_AddedRadio( added_radio )
{

}

// Construction
Cmp3RecordData::Cmp3RecordData( void )
: CzzDataService( "getRecordData" ), m_AddedRadio( "-" )
{

}

// Destruction
Cmp3RecordData::~Cmp3RecordData()
{

}


CzzDataServiceReply* Cmp3RecordData::execute( void* s, CzzParameterMap* req )
{
	CzzDataService::execute( s, req );

	CzzDataServiceReply* reply = new CzzDataServiceReply();
	CzzString bitrate;
	CzzString added;
	CzzString nowplaying = "-";
	CzzString commingup = "-";
	CzzString cgi = Cmp3Config::getCGIDir();
	CzzString path = Cmp3Config::getDataDir();
	CzzString name = (*req)[ MP3_CGI_PAR_NAME ];
	CzzString album = (*req)[ MP3_CGI_PAR_ALBUM ];
	char senast[1024];
	strcpy(senast,"-");
	unsigned int min = 0;
	unsigned int sec = 0;
	unsigned int antal = 0;
	float size = 0.0;
	long handle = 0;
	int error = 0;
	int result = 0;
	_finddata_t finfo;
	uint32 speed = 128;
	CzzString year("-");
    CzzString session = *((CzzString*)s);

	// Album
	reply->addField( MP3_FLD_LIST_ART, urlEncode( 
		CzzString::Format( "%s/%s/%s/Folder.jpg", 
		Cmp3Config::getMusicRoot().c_str(), 
		name.c_str(), album.c_str() ) ) );

	reply->addField( MP3_FLD_ALBUM_TITLE, album );
	reply->addField( MP3_FLD_ARTIST, name );

	// Find first file
	handle = _findfirst( (path + "\\" + name + "\\" + album + "\\*.mp3" ).c_str(), &finfo );

	// Read the dir
	if( (handle!= ENOENT)  && (handle != EINVAL) && (handle != -1) )
	{
		while( !error )
		{
			// We're not interested in the . and .. 
			if( (stricmp( finfo.name, "." ) != 0) && (stricmp( finfo.name, ".." ) != 0) )
			{
				// Is it a subdir?
				if( !(finfo.attrib & _A_SUBDIR) && !(finfo.attrib & _A_SYSTEM) )
				{
					try
					{
						ID3_Frame* frame = NULL;
						ID3_Field* fld = NULL;
						ID3_Tag tag( (path + "\\" + name + "\\" + album + "\\" + CzzString(finfo.name)).c_str() );
						const Mp3_Headerinfo* hdr = tag.GetMp3HeaderInfo();
						if( hdr != NULL )
						{
							if( hdr->bitrate != 0 )
								speed = hdr->bitrate/1000;
							if( hdr->vbr_bitrate != 0 )
								speed = hdr->vbr_bitrate/1000;
						}
						
						frame = tag.Find( ID3FID_YEAR );

						if( frame != NULL )
						{
							fld = frame->GetField( ID3FN_TEXT );
    
							if( fld != NULL )
							{
								fld->SetEncoding(ID3TE_ISO8859_1);
								const char* p = fld->GetRawText();

								if( p != NULL && strlen(p) == 4 && (p[0]=='1' || p[0]=='2') )
									year = p;
							}
						}
					}
					catch( ... ) {}
					error = 1;
				}
			}

			// Next file
			if( !error )
				error = _findnext( handle, &finfo );
		}
	}

	_findclose( handle );

	reply->addField( MP3_FLD_YEAR, year );
	reply->addField( MP3_FLD_BITRATE, CzzString::Format( "%d kbit/s", speed ) );

	// Radio
	try
	{
		Cmp3HttpRequester req;
		nowplaying = req.nowPlaying();
		commingup = req.commingUp();
	}
	catch( ... ) {}

	reply->addField( MP3_FLD_RADIO_LATEST_ADDED, m_AddedRadio );
	reply->addField( MP3_FLD_RADIO_NOW_PLAYING, nowplaying );
	reply->addField( MP3_FLD_RADIO_COMMING_UP, commingup );

	// Playlist
	GetPrivateProfileString("playlistinfo","latest","-",senast,sizeof(senast),(".\\" + session + ".ini").c_str() );
	size = GetPrivateProfileInt("playlistinfo","size",0,(".\\" + session + ".ini").c_str());
	sec = GetPrivateProfileInt("playlistinfo","seconds",0,(".\\" + session + ".ini").c_str());
	antal = GetPrivateProfileInt("playlistinfo","number",0,(".\\" + session + ".ini").c_str());
	
	min = sec/60;
	sec = sec - (min*60);

	reply->addField( MP3_FLD_M3U_LATEST_ADDED, senast );
	reply->addField( MP3_FLD_M3U_NO, CzzString::Format( "%d", antal ) );
	reply->addField( MP3_FLD_M3U_TIME, CzzString::Format( "%04d:%02d", min, sec ) );
	reply->addField( MP3_FLD_M3U_SIZE, CzzString::Format( "%.1f", size/(1000*1024) ) );

	// Links
	reply->addField( MP3_FLD_ADD_ALBUM_TO_RADIO, CzzString::Format( "%s/mp3_gui.exe?svc=%d&name=%s&album=%s", Cmp3Config::getCGIDir().c_str(), MP3_SVC_LIST_RADIO_ADD_RECORD, urlEncode(name).c_str(), urlEncode(album).c_str() ) );
	reply->addField( MP3_FLD_LIST_PLAYLIST, CzzString::Format( "%s/mp3_gui.exe?svc=%d&name=session", Cmp3Config::getCGIDir().c_str(), MP3_SVC_LIST_M3U_CONTENTS ) );
	reply->addField( MP3_FLD_PLAY_LINK, CzzString::Format( "%s/mp3_playlist.exe?svc=1&name=%s&album=%s", Cmp3Config::getCGIDir().c_str(), urlEncode(name).c_str(), urlEncode(album).c_str() ) );
	
	return reply;
}

int Cmp3RecordData::size()
{
    return sizeof(Cmp3RecordData);
}
