/* myMusic
 *
 * This program is distributed under the GNU General Public License, version 2.
 * A copy of this license is included with this source.
 *
 * Copyright 2004-2006, Toni Thomsson <toni@tonjac.org> 
*/

// Implementation of class Cmp3SongListData

#include "mp3_song_list_data.h"
#include "mp3_svc.h"
#include "mp3_config.h"

#include <time.h>
#include <sys/timeb.h>
#include <sys/types.h> 
#include <id3/tag.h>
#include <zz_file.h>
#include <winver.h>

// Construction
Cmp3SongListData::Cmp3SongListData( void )
: CzzDataService( "listSongData" )
{

}

// Destruction
Cmp3SongListData::~Cmp3SongListData()
{

}

CzzDataServiceReply* Cmp3SongListData::execute( void* session, CzzParameterMap* req )
{
	CzzDataService::execute( session, req );

	long handle = 0;
	int error = 0;
	int result = 0;
	_finddata_t finfo;
	CzzString cgi = Cmp3Config::getCGIDir();
	CzzString root = Cmp3Config::getRootDir();
	CzzString name = (*req)[ MP3_CGI_PAR_NAME ];
	CzzString album = (*req)[ MP3_CGI_PAR_ALBUM ];
	CzzString path = Cmp3Config::getDataDir();

	CzzDataServiceReply* reply = new CzzDataServiceReply();

	reply->addFieldName( MP3_FLD_SONG_TITLE );
	reply->addFieldName( MP3_FLD_SONG_LENGTH );
    reply->addFieldName( MP3_FLD_SONG_ORDER );
	reply->addFieldName( MP3_FLD_PLAY_SONG );
	reply->addFieldName( MP3_FLD_ADD_SONG_TO_PLAY_LIST );
	reply->addFieldName( MP3_FLD_ADD_SONG_TO_RADIO );


	// Find first file
	handle = _findfirst( (path + "\\" + name + "\\" + album + "\\*.mp3" ).c_str(), &finfo );

	// Read the dir
	if( (handle!= ENOENT)  && (handle != EINVAL) && (handle != -1) )
	{
		while( !error )
		{
			// We're not interested in the . and .. 
			if( (stricmp( finfo.name, "." ) != 0) && (stricmp( finfo.name, ".." ) != 0) )
			{
				// Is it a subdir?
				if( !(finfo.attrib & _A_SUBDIR) && !(finfo.attrib & _A_SYSTEM) )
					printSongList( name, album, finfo.name, reply );
			}

			// Next file
			error = _findnext( handle, &finfo );
		}
	}

	_findclose( handle );
			
	return reply;
}

void Cmp3SongListData::printSongList( const CzzString& name, const CzzString& album, const char* song, CzzDataServiceReply* reply )
{
	CzzString cgi = Cmp3Config::getCGIDir();
	CzzString path = Cmp3Config::getDataDir();

    const char* f = NULL;
	char* s = new char[strlen(song)+1];
    char* t = new char[strlen(song)+1];
	strcpy(s,song);
	s[ strlen( song )-4 ] = '\0';
    uint32 minutes = 0;
	uint32 secs = 0;
    int no = 0;

	try
	{
		ID3_Frame* frame = NULL;
		ID3_Field* fld = NULL;
		ID3_Tag tag( (path + "\\" + name + "\\" + album + "\\" + CzzString(song)).c_str() );
		const Mp3_Headerinfo* hdr = tag.GetMp3HeaderInfo();
		if( hdr != NULL )
		{
			minutes = hdr->time/60;
			secs = hdr->time - (minutes*60);
		}

        frame = tag.Find( ID3FID_TRACKNUM );

        if( frame != NULL )
        {
            fld = frame->GetField( ID3FN_TEXT );
			fld->SetEncoding(ID3TE_ISO8859_1);
            const char* p = fld->GetRawText();
            no = atoi( p );
        }

        frame = tag.Find( ID3FID_TITLE );

        if( frame != NULL )
        {
            fld = frame->GetField( ID3FN_TEXT );
			fld->SetEncoding(ID3TE_ISO8859_1);
            f = fld->GetRawText();
            strcpy( t, f );
        }
	}
	catch( ... ) {}

	/*
	reply->addFieldName( MP3_FLD_SONG_TITLE );
	reply->addFieldName( MP3_FLD_SONG_LENGTH );
    reply->addFieldName( MP3_FLD_SONG_ORDER );
	reply->addFieldName( MP3_FLD_PLAY_SONG );
	reply->addFieldName( MP3_FLD_ADD_SONG_TO_PLAY_LIST );
	reply->addFieldName( MP3_FLD_ADD_SONG_TO_RADIO );
	*/

    if( f )
	    reply->addFieldValue( t );
    else
        reply->addFieldValue( s );

	reply->addFieldValue( CzzString::Format( "%02d:%02d", minutes, secs ) );
    reply->addFieldValue( CzzString::Format( "%02d", no ) );
	reply->addFieldValue( CzzString::Format( "%s/mp3_playlist.exe?svc=2&name=%s&album=%s&song=%s.mp3", cgi.c_str(), urlEncode(name).c_str(), urlEncode(album).c_str(), urlEncode(s).c_str() ) );
	reply->addFieldValue( CzzString::Format( "%s/mp3_gui.exe?svc=%d&name=%s&album=%s&song=%s.mp3", cgi.c_str(), MP3_SVC_LIST_M3U_ADD, urlEncode(name).c_str(), urlEncode(album).c_str(), urlEncode(s).c_str() ) );
	reply->addFieldValue( CzzString::Format( "%s/mp3_gui.exe?svc=%d&name=%s&album=%s&song=%s.mp3", cgi.c_str(), MP3_SVC_LIST_RADIO_ADD, urlEncode(name).c_str(), urlEncode(album).c_str(), urlEncode(s).c_str() ) );

    delete [] s;
    delete [] t;
}

int Cmp3SongListData::size()
{
    return sizeof(Cmp3SongListData);
}