/* myMusic
 *
 * This program is distributed under the GNU General Public License, version 2.
 * A copy of this license is included with this source.
 *
 * Copyright 2004-2006, Toni Thomsson <toni@tonjac.org> 
*/

// Implementation of class Cmp3Track

#include "mp3_track.h"
#include <zz_path.h>

// Construction
Cmp3Track::Cmp3Track( const CzzString& artist, const CzzString& album, const char* file )
: m_Title(), m_Artist(artist), m_Time(0), m_Number(0), m_BitRate(128), m_Album(album), m_File(CzzPath::strip(file))
{
    readID3( file, m_Title, CzzString(), &m_Time, &m_Number, &m_BitRate );
}

// Destruction
Cmp3Track::~Cmp3Track()
{

}

CzzString Cmp3Track::getTitle( void )
{
    return m_Title;
}

CzzString Cmp3Track::getArtist( void )
{
    return m_Artist;
}

CzzString Cmp3Track::getAlbum( void )
{
    return m_Album;
}

CzzString Cmp3Track::getFile( void )
{
    return m_File;
}

int Cmp3Track::getNumber( void )
{
    return m_Number;
}

int Cmp3Track::getTime( void )
{
    return m_Time;
}

int Cmp3Track::getBitrate( void )
{
    return m_BitRate;
}

void Cmp3Track::readID3( const char* file, CzzString& title, CzzString& artist, uint32* time, uint32* no, uint32* speed )
{
	ID3_Frame* frame = NULL;
	ID3_Field* fld = NULL;
	ID3_Tag tag( file );
	const Mp3_Headerinfo* hdr = tag.GetMp3HeaderInfo();
	uint32 minutes = 0;
	uint32 secs = 0;

	if( hdr != NULL )
	{
		*time = hdr->time;
		minutes = hdr->time/60;
		secs = hdr->time - (minutes*60);
		if( hdr->bitrate != 0 )
			*speed = hdr->bitrate/1000;
		if( hdr->vbr_bitrate != 0 )
			*speed = hdr->vbr_bitrate/1000;
	}

	frame = tag.Find( ID3FID_TITLE );

	if( frame != NULL )
	{
		fld = frame->GetField( ID3FN_TEXT );

		if( fld != NULL )
		{
			fld->SetEncoding(ID3TE_ISO8859_1);
			title = fld->GetRawText();

            if( title.size() == 0 )
                title = CzzPath::strip( file );
		}
        else
            title = CzzPath::strip( file );
	}
    else
        title = CzzPath::strip( file );

	frame = tag.Find( ID3FID_LEADARTIST );

	if( frame != NULL )
	{
		fld = frame->GetField( ID3FN_TEXT );

		if( fld != NULL )
		{
			fld->SetEncoding(ID3TE_ISO8859_1);
			artist = fld->GetRawText();
		}
	}

    frame = tag.Find( ID3FID_TRACKNUM );

	if( frame != NULL )
	{
		fld = frame->GetField( ID3FN_TEXT );

		if( fld != NULL )
		{
			fld->SetEncoding(ID3TE_ISO8859_1);
			*no = atoi( fld->GetRawText() );
		}
	}
}

