/* libzzsock
 *
 * This program is distributed under the GNU General Public License, version 2.
 * A copy of this license is included with this source.
 *
 * Copyright 2000-2006, Toni Thomsson <toni@tonjac.org> 
*/

#ifndef zz_mail_h
#define zz_mail_h

#include <zz_export.h>

#ifdef _WIN32
	#pragma warning(disable: 4786) // Debugsymbols truncated
	#pragma warning(disable: 4251) // DLL-interface missing for private map members
#endif

#include <zz_string.h>
#include <zz_socket.h>
#include <map>

/**
    SMTP mail

    @author Toni Thomsson, toni@tonjac.org
*/
class ZZ_API CzzMail
{
public:

	/**
        Create a mail
        @param host             Mail host
        @param  sender          Sender mail adress
        @param  recipient       Receiver mail adress
        @param  subject         Subject
        @param  sendername      Sender name (optional)
        @param  recipientname   Receiver name (optional)
        @param  replyto         Reply to mail adress (optional)
        @param  replytoname     Reply to name (optional)
        @param  msgid           Id (optional)
    */
	CzzMail( const char* host,
				const char* sender,
				const char* recipient,
				const char* subject,
				const char* sendername = "",
				const char* recipientname = "",
				const char* replyto = "",
				const char* replytoname = "",
				const char* msgid = "" );

	virtual ~CzzMail();

	/**
		Add a textrow to the message
		@param  row Text
	*/
	void addMessageRow( const CzzString& row );

	/**
		Attach a file to the message.
        NOT IMPLEMENTED YET!
		@param  file Path to attachment
	*/
	void addAttachment( const CzzString& file ) {};

	/**
        Send message
	*/
	void sendMessage( void );

protected:

    /** Check for a reply */
	void checkReply( const char* replycode );

    /** Send */
	void send( const char* buff );

private:
	CzzString m_Host;
    CzzString m_Sender;
	CzzString m_SenderName;
	CzzString m_Recipient;
	CzzString m_RecipientName;
	CzzString m_ReplyTo;
	CzzString m_ReplyToName;
	CzzString m_MessageId;
	CzzString m_Subject;
	CzzSocket* m_Socket;
    map<int, CzzString > m_MessageRows;
};

#endif // zz_mail_h




